==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/media/kotlin/outputs/StreamingPolicyPlayReadyConfigurationResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.media.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Class to specify configurations of PlayReady in Streaming Policy
 * @property customLicenseAcquisitionUrlTemplate Template for the URL of the custom service delivering licenses to end user players.  Not required when using Azure Media Services for issuing licenses.  The template supports replaceable tokens that the service will update at runtime with the value specific to the request.  The currently supported token values are {AlternativeMediaId}, which is replaced with the value of StreamingLocatorId.AlternativeMediaId, and {ContentKeyId}, which is replaced with the value of identifier of the key being requested.
 * @property playReadyCustomAttributes Custom attributes for PlayReady
 */
public data class StreamingPolicyPlayReadyConfigurationResponse(
    public val customLicenseAcquisitionUrlTemplate: String? = null,
    public val playReadyCustomAttributes: String? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.media.outputs.StreamingPolicyPlayReadyConfigurationResponse):
            StreamingPolicyPlayReadyConfigurationResponse =
            StreamingPolicyPlayReadyConfigurationResponse(
                customLicenseAcquisitionUrlTemplate = javaType.customLicenseAcquisitionUrlTemplate().map({ args0 ->
                    args0
                }).orElse(null),
                playReadyCustomAttributes = javaType.playReadyCustomAttributes().map({ args0 ->
                    args0
                }).orElse(null),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/media/kotlin/outputs/StreamingPolicyPlayReadyConfigurationResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.media.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Class to specify configurations of PlayReady in Streaming Policy
 * @property customLicenseAcquisitionUrlTemplate Template for the URL of the custom service delivering licenses to end user players.  Not required when using Azure Media Services for issuing licenses.  The template supports replaceable tokens that the service will update at runtime with the value specific to the request.  The currently supported token values are {AlternativeMediaId}, which is replaced with the value of StreamingLocatorId.AlternativeMediaId, and {ContentKeyId}, which is replaced with the value of identifier of the key being requested.
 * @property playReadyCustomAttributes Custom attributes for PlayReady
 */
public data class StreamingPolicyPlayReadyConfigurationResponse(
    public val customLicenseAcquisitionUrlTemplate: String? = null,
    public val playReadyCustomAttributes: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.media.outputs.StreamingPolicyPlayReadyConfigurationResponse): StreamingPolicyPlayReadyConfigurationResponse =
            StreamingPolicyPlayReadyConfigurationResponse(
                customLicenseAcquisitionUrlTemplate = javaType.customLicenseAcquisitionUrlTemplate().map({ args0 ->
                    args0
                }).orElse(null),
                playReadyCustomAttributes = javaType.playReadyCustomAttributes().map({ args0 ->
                    args0
                }).orElse(null),
            )
    }
}
